@@ -34,7 +34,7 @@ import playerfactory as PlayerFactory
 import mediasong as MediaSong
 
 # The current version of Kap
-_VERSION = "0.3.0"
+_VERSION = "0.4.0"
 
 
 class Kap(wx.Frame):
@@ -329,6 +329,7 @@ class Kap(wx.Frame):
         wx.EVT_BUTTON(self, self.__playerWindow.ID_STOP, self.__onStopSong)
         wx.EVT_COMMAND_SCROLL(self, self.__playerWindow.ID_VOLUME, \
             self.__onChangeVolume)
+        wx.EVT_BUTTON(self, self.__playerWindow.ID_MUTE, self.__onVolumeMute)
         wx.EVT_COMMAND_SCROLL(self, self.__playerWindow.ID_TRACK_POSITION, \
             self.__onChangeTrackPosition)
 
@@ -547,6 +548,7 @@ class Kap(wx.Frame):
                 self.__playerWindow.togglePlay()
                 self.StatusBar.SetStatusText("Loaded: %s - %s" % (song.title, \
                     song.artist), self.__PLAYER_STATUS_FIELD)
+                self.__database.incrementSongPlayed(song)
                 self.__currentSong = song
             else:
                 wx.MessageBox("Could not start player or load media file!", \
@@ -575,6 +577,15 @@ class Kap(wx.Frame):
         else:
             self.__playerWindow.setVolumeLevel(self.__volumeLevel)
 
+    def __onVolumeMute(self, event):
+        """ Mutes the player volume levels.
+
+         Updates the player volume levels from the player interface.
+         wx.Event event: is the event object (Not Used)
+        """
+        self.__playerWindow.toggleMute()
+        self.__onChangeVolume(event)
+
     def __onChangeTrackPosition(self, event):
         """ Changes the player track position.
 
@@ -702,11 +713,11 @@ def main(args):
 
     pySmplAppKap = wx.PySimpleApp()
     sfCnfgPrsrKap = ConfigParser.SafeConfigParser()
-    sfCnfgPrsrKap.read('kap.cfg')
+    sfCnfgPrsrKap.read('kap.config')
     kap = Kap(None, wx.ID_ANY, sfCnfgPrsrKap)
     kap.Show(True)
     pySmplAppKap.MainLoop()
-    configfile = open('kap.cfg', 'wb')
+    configfile = open('kap.config', 'wb')
     sfCnfgPrsrKap.write(configfile)
 
 if __name__ == "__main__":
