@@ -84,7 +84,7 @@ class MediaSong():
          string path: is the absolute path to the file.
          return MediaSong: The created MediaSong object
         """
-        self.artist = artist
-        self.title = title
+        self.artist = unicode(artist, 'latin-1').encode('UTF-8', 'replace')
+        self.title = unicode(title, 'latin-1').encode('UTF-8', 'replace')
         self.blIsVideo = isVideo
         self.filePath = path.replace("\"", "\\\"")
