@@ -100,6 +100,8 @@ class PlayerThread(Thread):
     signalPlayerPositionTime = None
     # Player command for setting the playing position in the song.
     signalSetPlayerPositionTime = None
+    # Player command for displaying the player in full screen.
+    signalFullScreen = None
 
     """
      SIGNAL COMMANDS
@@ -126,6 +128,8 @@ class PlayerThread(Thread):
     __commandSetPositionTime = hex(0x9)
     # Indicates the player has reached the end of a song.
     __commandSongEnd = hex(0xA)
+    # Indicates the player should display the song at full screen.
+    __commandFullScreen = hex(0xB)
 
     def __init__(self, playerCommand, arguments, volumeLevel):
         """ Create and start the player thread.
@@ -206,6 +210,13 @@ class PlayerThread(Thread):
                     self.__blIsStarting = False
                 print "Player Thread End Of Signal Play"
 
+            # Signal to display song at full screen
+            if command == self.__commandFullScreen:
+                print "Player Thread Running Signal FullScreen: %s" % \
+                    self.signalFullScreen
+                self.__writeStandardInput('%s\n' % self.signalFullScreen)
+                print "Player Thread End Of Signal FullScreen"
+
             # Signal to stop the song
             if command == self.__commandStop:
                 print "Player Thread Running Signal Stop: %s" % \
@@ -403,6 +414,13 @@ class PlayerThread(Thread):
         self.__cndtnRunCommand.notify()
         self.__cndtnRunCommand.release()
 
+    def fullScreen(self):
+        """ Issues the command to display the current song full screen. """
+        self.__pushCommand(self.__commandFullScreen)
+        self.__cndtnRunCommand.acquire()
+        self.__cndtnRunCommand.notify()
+        self.__cndtnRunCommand.release()
+
     def play(self, filePath, volume):
         """ Issues the command to play a song.
 
